==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PieChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieChartBaseDescriptionMetadata } from "./PieChartBaseDescriptionMetadata";
import { PieChartDescription } from "./PieChartDescription";
/**
 * @hidden
 */
var PieChartDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PieChartDescriptionMetadata, _super);
    function PieChartDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PieChartDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamPieChart");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    PieChartDescriptionMetadata.b = function (a) {
        if (PieChartDescriptionMetadata.a == null) {
            PieChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PieChartDescriptionMetadata.c(PieChartDescriptionMetadata.a);
        }
        if (a.g(PieChartDescriptionMetadata.a)) {
            return;
        }
        a.s(PieChartDescriptionMetadata.a);
    };
    PieChartDescriptionMetadata.c = function (a) {
        PieChartBaseDescriptionMetadata.c(a);
        PieChartDescriptionMetadata.e(a);
    };
    PieChartDescriptionMetadata.d = function (a) {
        PieChartDescriptionMetadata.b(a);
        a.u("PieChart", function () { return new PieChartDescription(); });
        a.t("PieChart", PieChartDescriptionMetadata.a);
    };
    PieChartDescriptionMetadata.$t = markType(PieChartDescriptionMetadata, 'PieChartDescriptionMetadata');
    PieChartDescriptionMetadata.a = null;
    return PieChartDescriptionMetadata;
}(Base));
export { PieChartDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PieChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieChartBaseDescriptionMetadata } from "./PieChartBaseDescriptionMetadata";
import { PieChartDescription } from "./PieChartDescription";
/**
 * @hidden
 */
var PieChartDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PieChartDescriptionMetadata, _super);
    function PieChartDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PieChartDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamPieChart");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    PieChartDescriptionMetadata.b = function (a) {
        if (PieChartDescriptionMetadata.a == null) {
            PieChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PieChartDescriptionMetadata.c(PieChartDescriptionMetadata.a);
        }
        if (a.j(PieChartDescriptionMetadata.a)) {
            return;
        }
        a.y(PieChartDescriptionMetadata.a);
    };
    PieChartDescriptionMetadata.c = function (a) {
        PieChartBaseDescriptionMetadata.c(a);
        PieChartDescriptionMetadata.e(a);
    };
    PieChartDescriptionMetadata.d = function (a) {
        PieChartDescriptionMetadata.b(a);
        a.aa("PieChart", function () { return new PieChartDescription(); });
        a.z("PieChart", PieChartDescriptionMetadata.a);
    };
    PieChartDescriptionMetadata.$t = markType(PieChartDescriptionMetadata, 'PieChartDescriptionMetadata');
    PieChartDescriptionMetadata.a = null;
    return PieChartDescriptionMetadata;
}(Base));
export { PieChartDescriptionMetadata };
